@@ -12,10 +12,8 @@ from werkzeug import find_modules, import_string
 
 __all__ = ('build_suite', 'run_tests')
 
-
 TEST_MODULE = 'tests'
 
-
 def build_suite(name):
     """Build test suite for the given name. A name can be either a package name
     or a fully qualified name of the test class or a specific test method within
@@ -70,7 +68,6 @@ def build_suite(name):
 
     return suite
 
-
 def run_tests(names, verbosity=1):
     """Run unittests for all the test names.
 
@@ -90,12 +87,13 @@ def run_tests(names, verbosity=1):
     :param verbosity: verbose level
     """
 
+    from kalapy.core.pool import pool
     from kalapy.db.engines import database
-    from kalapy.conf.loader import loader
 
     database.connect()
     try:
-        loader.load() # load all packages
+        # Initialize the object pool
+        pool.load()
         suite = unittest.TestSuite()
         for name in names:
             suite.addTest(build_suite(name))
@@ -104,4 +102,3 @@ def run_tests(names, verbosity=1):
         database.close()
 
     return len(result.failures) + len(result.errors)
-
